import { shallowMount } from '@vue/test-utils';
import { GlDatepicker } from '@gitlab/ui';
import ExpiresAtField from '~/access_tokens/components/expires_at_field.vue';

describe('~/access_tokens/components/expires_at_field', () => {
  let wrapper;

  const defaultPropsData = {
    inputAttrs: {
      id: 'personal_access_token_expires_at',
      name: 'personal_access_token[expires_at]',
      placeholder: 'YYYY-MM-DD',
    },
  };

  const findDatepicker = () => wrapper.findComponent(GlDatepicker);

  const createComponent = (props = {}) => {
    wrapper = shallowMount(ExpiresAtField, {
      propsData: {
        ...defaultPropsData,
        ...props,
      },
    });
  };

  afterEach(() => {
    wrapper.destroy();
  });

  it('should render datepicker with input info', () => {
    createComponent();

    expect(wrapper.element).toMatchSnapshot();
  });

  it('should set the date pickers minimum date', () => {
    const minDate = new Date('1970-01-01');

    createComponent({ minDate });

    expect(findDatepicker().props('minDate')).toStrictEqual(minDate);
  });

  it('should set the date pickers maximum date', () => {
    const maxDate = new Date('1970-01-01');

    createComponent({ maxDate });

    expect(findDatepicker().props('maxDate')).toStrictEqual(maxDate);
  });
});
